/*
 ***************************
 *   Basic AJAX function   *
 *    © Pascal Pfiffner    *
 ***************************
 **
 ** Usage:
 ** var ajax = new simpleAjaxRequest([string] uri, [function] handleFunction, [bool] forceText, [any] extraArguments);
 ** 
 ** on success, handleFunction gets called with the resulting text/xml as the first argument and extraArguments as the second (which just gets passed along)
 **
 */


function simpleAjaxRequest(url, handlefunction, forceText, extraArguments) {
	if(!(this instanceof simpleAjaxRequest)) {
		return new simpleAjaxRequest(url, handlefunction, forceText, extraArguments);
	}
	
	var req = null;
	
	// sends a request for a page and calls the handlefunction, which will get 'null' if the request was unsuccessful
	this.requestPage = function() {
		try {
			req = createXMLHttpRequest();
			req.onreadystatechange = function() {
				if(4 == req.readyState) {
					handlefunction(forceText ? req.responseText : req.responseXML, extraArguments);
				}
			}
			
			req.open("GET", url, true);
			req.setRequestHeader("Cache-Control", "no-cache");
			req.send(null);
			return true;
		}
		
		catch(exc){
			//alert('[simpleAjaxRequest.requestPage] Error: ' + exc);
			handlefunction(null);
			return false;
		}
	}
	
	
	// returns a new XMLHttpRequest-Object. Needed because MSIE has another implementation
	var createXMLHttpRequest = function() {
		var request = null;
		
		if(window.XMLHttpRequest) {
			request = new XMLHttpRequest;
		}
		else if(window.ActiveXObject) {
			try {
				request = new ActiveXObject("Msxml2.XMLHTTP");
			}
			catch(err_MSXML2) {
				try {
					request = new ActiveXObject("Microsoft.XMLHTTP");
				}
				catch(err_Microsoft) { }
			}
		}
		
		return request;
	}
	
	return this.requestPage(url, handlefunction, forceText);
}


